jamtorch.trainer package
========================

Submodules
----------

jamtorch.trainer.amp module
---------------------------

.. automodule:: jamtorch.trainer.amp
   :members:
   :undoc-members:
   :show-inheritance:

jamtorch.trainer.cfg\_trainer module
------------------------------------

.. automodule:: jamtorch.trainer.cfg_trainer
   :members:
   :undoc-members:
   :show-inheritance:

jamtorch.trainer.ema\_trainer module
------------------------------------

.. automodule:: jamtorch.trainer.ema_trainer
   :members:
   :undoc-members:
   :show-inheritance:

jamtorch.trainer.genetic\_trainer module
----------------------------------------

.. automodule:: jamtorch.trainer.genetic_trainer
   :members:
   :undoc-members:
   :show-inheritance:

jamtorch.trainer.hydra\_utils module
------------------------------------

.. automodule:: jamtorch.trainer.hydra_utils
   :members:
   :undoc-members:
   :show-inheritance:

jamtorch.trainer.monitor module
-------------------------------

.. automodule:: jamtorch.trainer.monitor
   :members:
   :undoc-members:
   :show-inheritance:

jamtorch.trainer.progress\_fn module
------------------------------------

.. automodule:: jamtorch.trainer.progress_fn
   :members:
   :undoc-members:
   :show-inheritance:

jamtorch.trainer.simple\_trainer module
---------------------------------------

.. automodule:: jamtorch.trainer.simple_trainer
   :members:
   :undoc-members:
   :show-inheritance:

jamtorch.trainer.tb module
--------------------------

.. automodule:: jamtorch.trainer.tb
   :members:
   :undoc-members:
   :show-inheritance:

jamtorch.trainer.test\_trainer module
-------------------------------------

.. automodule:: jamtorch.trainer.test_trainer
   :members:
   :undoc-members:
   :show-inheritance:

jamtorch.trainer.trainer module
-------------------------------

.. automodule:: jamtorch.trainer.trainer
   :members:
   :undoc-members:
   :show-inheritance:

jamtorch.trainer.trainer\_fn module
-----------------------------------

.. automodule:: jamtorch.trainer.trainer_fn
   :members:
   :undoc-members:
   :show-inheritance:

jamtorch.trainer.trainer\_monitor module
----------------------------------------

.. automodule:: jamtorch.trainer.trainer_monitor
   :members:
   :undoc-members:
   :show-inheritance:

jamtorch.trainer.utils module
-----------------------------

.. automodule:: jamtorch.trainer.utils
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: jamtorch.trainer
   :members:
   :undoc-members:
   :show-inheritance:
